@@ -898,7 +898,7 @@ class RedisRoot:
                 }
         return instances
 
-    def _get_all_model_instances(self, model, filters=None):
+    def _get_all_redis_model_instances(self, model, filters=None):
         if filters is None:
             filters = {}
         instances_with_allowed = self._get_all_stored_model_instances(model, filters)
@@ -914,11 +914,14 @@ class RedisRoot:
         else:
             raise Exception(f'Django model {django_model} is not registered in redis cache')
 
-    def get(self, django_model, return_dict=False, **filters):
-        model = self._django_model_to_redis_model(django_model)
-        instances = self._get_all_model_instances(model, filters)
+    def get_by_redis_model(self, redis_model, return_dict=False, **filters):
+        instances = self._get_all_redis_model_instances(redis_model, filters)
         return self._return_with_format(instances, return_dict)
 
+    def get(self, django_model, return_dict=False, **filters):
+        redis_model = self._django_model_to_redis_model(django_model)
+        return self.get_by_redis_model(redis_model, return_dict, **filters)
+
     def order(self, instances, field_name):
         reverse = False
         if field_name.startswith('-'):
@@ -1150,7 +1153,7 @@ class RedisModel:
 
     def _get_new_id(self):
         redis_root = self.__model_data__['redis_root']
-        instances_with_ids = redis_root.get(self.__class__, return_dict=True)
+        instances_with_ids = redis_root.get_by_redis_model(self.__class__, return_dict=True)
         all_ids = [int(instance_id) for instance_id in list(instances_with_ids.keys())]
         if all_ids:
             max_id = max(all_ids)
